@@ -1,7 +1,7 @@
 # Accelerator for pip, the Python package manager.
 #
 # Author: Peter Odding <peter.odding@paylogic.eu>
-# Last Change: May 18, 2014
+# Last Change: May 24, 2014
 # URL: https://github.com/paylogic/pip-accel
 #
 # TODO Permanently store logs in the pip-accel directory (think about log rotation).
@@ -20,9 +20,10 @@ taking a look at the following functions:
 """
 
 # Semi-standard module versioning.
-__version__ = '0.12.2'
+__version__ = '0.12.5'
 
 # Standard library modules.
+import logging
 import os
 import os.path
 import pipes
@@ -45,7 +46,6 @@ from pip_accel.bdist import get_binary_dist, install_binary_dist
 from pip_accel.config import (binary_index, download_cache,
                               index_version_file, source_index)
 from pip_accel.req import Requirement
-from pip_accel.logger import logger
 
 # External dependencies.
 import coloredlogs
@@ -59,6 +59,9 @@ from pip.exceptions import DistributionNotFound, InstallationError
 from pip.log import logger as pip_logger
 from pip.status_codes import SUCCESS
 
+# Initialize a logger for this module.
+logger = logging.getLogger(__name__)
+
 # Find the environment where requirements are to be installed.
 ENVIRONMENT = os.path.abspath(os.environ.get('VIRTUAL_ENV', sys.prefix))
 
