@@ -1,7 +1,7 @@
 # Extension of pip-accel that deals with dependencies on system packages.
 #
 # Author: Peter Odding <peter.odding@paylogic.eu>
-# Last Change: May 11, 2014
+# Last Change: May 24, 2014
 # URL: https://github.com/paylogic/pip-accel
 
 """
@@ -14,6 +14,7 @@ are supported by this extension.
 """
 
 # Standard library modules.
+import logging
 import os
 import os.path
 
@@ -24,8 +25,8 @@ except ImportError:
     # Python 3.x.
     import configparser
 
-# Internal modules.
-from pip_accel.logger import logger
+# Initialize a logger for this module.
+logger = logging.getLogger(__name__)
 
 def sanity_check_dependencies(project_name, auto_install=None):
     """
@@ -176,8 +177,24 @@ class BasePlatform(object):
         return self.dependencies.get(project_name.lower(), [])
 
     def find_installed(self):
+        """
+        Find the packages that are installed on the current system.
+
+        :returns: A list of strings with package names.
+        """
         return []
 
+    def install_command(self, missing_packages):
+        """
+        Determine the command line needed to install the given package(s).
+
+        :param missing_packages: A list with the names of one or more system
+                                 packages to be installed.
+
+        :returns: A list containing the program name and its arguments.
+        """
+        raise NotImplemented
+
 class DebianLinux(BasePlatform):
 
     """
